@@ -88,7 +88,7 @@ def get_url(routename, **kwargs):
 
 
 def init_tpl_response(action='', title=''):
-    '''Create a dicionary with the minimal info needed to render a template
+    '''Create a dictionary with the minimal info needed to render a template
     '''
     return {
         'get_url': app.get_url,
